AroonOscillator

Struct AroonOscillator 

pub struct AroonOscillator {
    pub period: usize,
    pub aroon_up: f64,
    pub aroon_down: f64,
    pub value: f64,
    pub count: usize,
    pub initialized: bool,
    /* private fields */
}
The Aroon Oscillator calculates the Aroon Up and Aroon Down indicators to determine if an instrument is trending, and the strength of the trend.

Fields

period: usizearoon_up: f64aroon_down: f64value: f64count: usizeinitialized: bool

Implementations

Source

impl AroonOscillator

pub fn new(period: usize) -> Self

Creates a new AroonOscillator instance.

Panics

Panics if period is not positive (> 0).

pub fn update_raw(&mut self, high: f64, low: f64)

Source

impl AroonOscillator

pub fn py_new(period: usize) -> Self

The Aroon Oscillator calculates the Aroon Up and Aroon Down indicators to determine if an instrument is trending, and the strength of the trend.